package cz.frantovo.obrazkovyApplet;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.URL;
import java.net.URLConnection;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.imageio.ImageIO;
import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;

/**
 * @author František Kučera, podnik.frantovo.cz
 */
public class ObrazkovyApplet extends javax.swing.JApplet implements MouseMotionListener, MouseListener {

	private static final Logger log = Logger.getLogger(ObrazkovyApplet.class.getSimpleName());
	private static final String CILOVE_URL = "http://vm.frantovo.cz/temp/applet/";
	private int stareX;
	private int stareY;
	private boolean kresli;
	private Platno platno;

	private void odesliData() {
		try {
			URL url = new URL(CILOVE_URL);
			URLConnection spojeni = url.openConnection();
			spojeni.setDoOutput(true);
			spojeni.connect();
			OutputStream os = spojeni.getOutputStream();
			ImageIO.write(platno.getObrazek(), "png", os);
			os.flush();
			os.close();

			BufferedReader r = new BufferedReader(new InputStreamReader(spojeni.getInputStream()));
			vypisStav(r.readLine());
			r.close();

			smazGrafiku();
		} catch (Exception e) {
			vypisStav("odeslání selhalo: " + e.getMessage());
			log.log(Level.SEVERE, "Nepodařilo se odeslat data", e);
		}
	}

	private void smazGrafiku() {
		platno.getObrazek().getGraphics().fillRect(0, 0, panel.getWidth(), panel.getHeight());
		platno.repaint();
	}

	public void mouseDragged(MouseEvent e) {
		int x = e.getX();
		int y = e.getY();

		if (kresli) {
			vypisStav("kreslím: " + stareX + "x" + stareY + "→" + x + "x" + y);

			Graphics g = platno.getObrazek().getGraphics();
			g.setColor(Color.BLUE);
			g.drawLine(stareX, stareY, x, y);

			platno.repaint();
		}

		stareX = x;
		stareY = y;
	}

	public void mousePressed(MouseEvent e) {
		stareX = e.getX();
		stareY = e.getY();
		kresli = true;
	}

	public void mouseReleased(MouseEvent e) {
		kresli = false;
	}

	public void mouseMoved(MouseEvent e) {
	}

	public void mouseClicked(MouseEvent e) {
	}

	public void mouseEntered(MouseEvent e) {
	}

	public void mouseExited(MouseEvent e) {
		kresli = false;
	}

	@Override
	public void init() {

		/** Lepší vzhled – LaF */
		try {
			for (LookAndFeelInfo info : UIManager.getInstalledLookAndFeels()) {
				if ("Nimbus".equals(info.getName())) {
					UIManager.setLookAndFeel(info.getClassName());
					break;
				}
			}
		} catch (Exception e) {
		}

		/** Spuštění appletu */
		try {
			java.awt.EventQueue.invokeAndWait(new Runnable() {

				public void run() {
					platno = new Platno();
					platno.repaint();
					initComponents();
					panel.setLayout(new BorderLayout());
					panel.add(platno, BorderLayout.CENTER);
				}
			});
		} catch (Exception e) {
			log.log(Level.SEVERE, "Chyba appletu:", e);
		}

		/** Nastavení plátna */
		panel.addMouseMotionListener(ObrazkovyApplet.this);
		panel.addMouseListener(ObrazkovyApplet.this);
		log.log(Level.INFO, "plátno nastaveno");
	}

	@SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        odeslat = new javax.swing.JButton();
        stavovyRadek = new javax.swing.JLabel();
        panel = new javax.swing.JPanel();

        odeslat.setText("Odeslat na server");
        odeslat.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                odeslatActionPerformed(evt);
            }
        });

        stavovyRadek.setText(" ");

        javax.swing.GroupLayout panelLayout = new javax.swing.GroupLayout(panel);
        panel.setLayout(panelLayout);
        panelLayout.setHorizontalGroup(
            panelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 388, Short.MAX_VALUE)
        );
        panelLayout.setVerticalGroup(
            panelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 255, Short.MAX_VALUE)
        );

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(panel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(stavovyRadek, javax.swing.GroupLayout.DEFAULT_SIZE, 243, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(odeslat)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(panel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(odeslat)
                    .addComponent(stavovyRadek))
                .addContainerGap())
        );
    }// </editor-fold>//GEN-END:initComponents

	private void odeslatActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_odeslatActionPerformed
		odesliData();
	}//GEN-LAST:event_odeslatActionPerformed

	private void vypisStav(String text) {
		stavovyRadek.setText(text);
	}
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton odeslat;
    private javax.swing.JPanel panel;
    private javax.swing.JLabel stavovyRadek;
    // End of variables declaration//GEN-END:variables
}
